DownloadInterruptReason

Enum DownloadInterruptReason 

#[non_exhaustive]
pub enum DownloadInterruptReason {
Show 31 variants None, FileFailed, FileAccessDenied, FileNoSpace, FileNameTooLong, FileTooLarge, FileMalicious, FileTransientError, FileBlockedByPolicy, FileSecurityCheckFailed, FileTooShort, FileHashMismatch, NetworkFailed, NetworkTimeout, NetworkDisconnected, NetworkServerDown, NetworkInvalidRequest, ServerFailed, ServerNoRange, ServerBadContent, ServerUnauthorized, ServerCertificateProblem, ServerForbidden, ServerUnexpectedResponse, ServerContentLengthMismatch, ServerCrossOriginRedirect, UserCanceled, UserShutdown, UserPaused, DownloadProcessCrashed, Unknown,
}
Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


None

No interruption; the download is progressing or completed.



FileFailed

A file-system operation failed.



FileAccessDenied

The destination file could not be accessed.



FileNoSpace

The destination has insufficient free space.



FileNameTooLong

The destination file name is too long.



FileTooLarge

The file exceeds an allowed size.



FileMalicious

The file was identified as malicious.



FileTransientError

A temporary file-system error interrupted the download.



FileBlockedByPolicy

Policy blocked the file.



FileSecurityCheckFailed

A file security check failed.



FileTooShort

The received file was shorter than expected.



FileHashMismatch

The received file’s hash did not match.



NetworkFailed

The network request failed.



NetworkTimeout

The network request timed out.



NetworkDisconnected

The network connection was lost.



NetworkServerDown

The network server is unavailable.



NetworkInvalidRequest

The network request was invalid.



ServerFailed

The server reported a failure.



ServerNoRange

The server does not support the required byte range.



ServerBadContent

The server returned invalid content.



ServerUnauthorized

The server requires authorization.



ServerCertificateProblem

The server certificate could not be accepted.



ServerForbidden

The server forbade the request.



ServerUnexpectedResponse

The server returned an unexpected response.



ServerContentLengthMismatch

The received length did not match the server’s declared content length.



ServerCrossOriginRedirect

A cross-origin server redirect interrupted the download.



UserCanceled

The user canceled the download.



UserShutdown

The user shut down the browser.



UserPaused

The user paused the download.



DownloadProcessCrashed

The process responsible for the download crashed.



Unknown

An interrupt reason not represented by the other variants.