PermissionKind

Enum PermissionKind 

#[non_exhaustive]
pub enum PermissionKind {
Show 13 variants Unknown, Microphone, Camera, Geolocation, Notifications, OtherSensors, ClipboardRead, MultipleAutomaticDownloads, FileReadWrite, Autoplay, LocalFonts, MidiSystemExclusiveMessages, WindowManagement,
}
The kind of capability a page is requesting in a PermissionRequestedArgs.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Unknown

A permission kind not represented by the other variants.



Microphone

Access to the microphone.



Camera

Access to the camera.



Geolocation

Access to the device location.



Notifications

Permission to show notifications.



OtherSensors

Access to device sensors other than location.



ClipboardRead

Permission to read the clipboard.



MultipleAutomaticDownloads

Permission to start multiple downloads automatically.



FileReadWrite

Access to files on the device.



Autoplay

Permission to play media without user interaction.



LocalFonts

Access to locally installed fonts.



MidiSystemExclusiveMessages

Access to system-exclusive MIDI messages.



WindowManagement

Permission to inspect and place windows on screens.