pub fn webview_result(
on_ready: impl IntoPayloadCallback<Result<WebView, IntegrationError>>,
) -> ViewExpand description
Hosts a WebView2 and reports initialization success or failure on the UI thread.
pub fn webview_result(
on_ready: impl IntoPayloadCallback<Result<WebView, IntegrationError>>,
) -> ViewHosts a WebView2 and reports initialization success or failure on the UI thread.