pub struct ContentLoadingArgs(/* private fields */);Expand description
Details about content that is starting to load, delivered to a
WebView::on_content_loading handler.
Implementations
Sourceimpl ContentLoadingArgs
impl ContentLoadingArgs
Sourcepub fn is_error_page(&self) -> bool
pub fn is_error_page(&self) -> bool
Returns true if the loading content is the error page.
Returns the unique identifier for the navigation.