CookieManager

Struct CookieManager 

pub struct CookieManager(/* private fields */);
Reads, writes, and deletes the browser’s cookies. Obtain it with WebView::cookie_manager.

Implementations

Source

impl CookieManager

pub fn get_cookies<F: FnOnce(Result<Vec<Cookie>>) + 'static>( &self, uri: &str, handler: F, ) -> Result<()>

Asynchronously retrieves the cookies that apply to uri (or all cookies when uri is empty). The handler closure receives them on the UI thread.

Adds the cookie, or updates the existing cookie with the same name, domain, and path.

pub fn delete_cookies(&self, name: &str, uri: &str) -> Result<()>

Deletes cookies with the matching name that apply to uri.

pub fn delete_cookies_with_domain_and_path( &self, name: &str, domain: &str, path: &str, ) -> Result<()>

Deletes cookies with the matching name, domain, and path.

pub fn delete_all_cookies(&self) -> Result<()>

Deletes all cookies.