pub struct NavigationStartingArgs(/* private fields */);Expand description
Details about a navigation that is about to start.
Implementations
Sourcepub fn is_user_initiated(&self) -> bool
pub fn is_user_initiated(&self) -> bool
Returns true if the navigation was initiated by the user (for example a
link click) rather than by script.
Sourcepub fn is_redirected(&self) -> bool
pub fn is_redirected(&self) -> bool
Returns true if the navigation is a redirect.
Returns the unique identifier for the navigation.
Sourcepub fn is_cancelled(&self) -> bool
pub fn is_cancelled(&self) -> bool
Returns true if the navigation is currently marked to be canceled.
Sourcepub fn set_cancel(&self, cancel: bool) -> Result<()>
pub fn set_cancel(&self, cancel: bool) -> Result<()>
Sets whether the navigation is canceled.