pub struct NewWindowRequestedArgs(/* private fields */);Expand description
Details about a page requesting to open a new window.
Implementations
Sourceimpl NewWindowRequestedArgs
impl NewWindowRequestedArgs
Sourcepub fn is_user_initiated(&self) -> bool
pub fn is_user_initiated(&self) -> bool
Returns true if the request was initiated by the user rather than by
script.
Sourcepub fn is_handled(&self) -> bool
pub fn is_handled(&self) -> bool
Returns true if the request has been marked as handled.
Sourcepub fn set_handled(&self, handled: bool) -> Result<()>
pub fn set_handled(&self, handled: bool) -> Result<()>
Marks the request as handled, suppressing the creation of a default new window. Set this (without providing a new window) to block the popup entirely.