#[non_exhaustive]pub enum ProcessFailedKind {
Unknown,
BrowserProcessExited,
RenderProcessExited,
RenderProcessUnresponsive,
FrameRenderProcessExited,
UtilityProcessExited,
SandboxHelperProcessExited,
GpuProcessExited,
PpapiPluginProcessExited,
PpapiBrokerProcessExited,
UnknownProcessExited,
}Expand description
The kind of process that failed, reported by ProcessFailedArgs::kind.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Unknown
A process failure kind not represented by the other variants.
BrowserProcessExited
The browser process ended unexpectedly; the WebView is no longer usable.
RenderProcessExited
A render process ended unexpectedly (a renderer crash); the page is gone
but the WebView can be reloaded.
RenderProcessUnresponsive
A render process is unresponsive (hung).
FrameRenderProcessExited
A frame’s render process ended unexpectedly.
UtilityProcessExited
A utility process ended unexpectedly.
SandboxHelperProcessExited
A sandbox helper process ended unexpectedly.
GpuProcessExited
The GPU process ended unexpectedly.
PpapiPluginProcessExited
A PPAPI plugin process ended unexpectedly.
PpapiBrokerProcessExited
A PPAPI broker process ended unexpectedly.
UnknownProcessExited
An unrecognized process ended unexpectedly.