pub struct CookieManager(/* private fields */);Expand description
Reads, writes, and deletes the browser’s cookies. Obtain it with
WebView::cookie_manager.
Implementations
Sourceimpl CookieManager
impl CookieManager
Asynchronously retrieves the cookies that apply to uri (or all cookies
when uri is empty). The handler closure receives them on the UI
thread.
Adds the cookie, or updates the existing cookie with the same name, domain, and path.
Deletes cookies with the matching name that apply to uri.
Deletes cookies with the matching name, domain, and path.
Deletes all cookies.