NavigationStartingArgs

Struct NavigationStartingArgs 

pub struct NavigationStartingArgs(/* private fields */);
Details about a navigation that is about to start.

Implementations

Source

impl NavigationStartingArgs

pub fn uri(&self) -> String

Returns the URI the navigation is targeting.

pub fn is_user_initiated(&self) -> bool

Returns true if the navigation was initiated by the user (for example a link click) rather than by script.

pub fn is_redirected(&self) -> bool

Returns true if the navigation is a redirect.

pub fn navigation_id(&self) -> u64

Returns the unique identifier for the navigation.

pub fn is_cancelled(&self) -> bool

Returns true if the navigation is currently marked to be canceled.

pub fn set_cancel(&self, cancel: bool) -> Result<()>

Sets whether the navigation is canceled.